More
====

.. toctree::
   :maxdepth: 2
   :caption: References

   references

.. toctree::
   :maxdepth: 2
   :caption: External resources

   ReacNetGenerator paper <https://doi.org/10.1039/C9CP05091D>
   Accepted manuscript <https://scholarship.libraries.rutgers.edu/view/pdfCoverPage?instCode=01RUT_INST&filePid=13678734780004646&download=true>
   GitHub <https://github.com/tongzhugroup/reacnetgenerator>
   Research group <https://computchem.cn>
   Jinzhe Zeng <https://njzjz.win/cv/>
